Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
lib/__init__.py | (no function) | 4 | 0 | 0 | 100%
lib/optwps.py | ROIGenerator.__init__ | 2 | 2 | 0 | 0%
lib/optwps.py | ROIGenerator.regions | 23 | 23 | 0 | 0%
lib/optwps.py | WPS.__init__ | 9 | 9 | 0 | 0%
lib/optwps.py | WPS.__call__ | 1 | 1 | 0 | 0%
lib/optwps.py | WPS.run | 77 | 77 | 0 | 0%
lib/optwps.py | (no function) | 13 | 0 | 0 | 100%
lib/utils.py | is_soft_clipped | 1 | 1 | 0 | 0%
lib/utils.py | ref_aln_length | 1 | 1 | 0 | 0%
lib/utils.py | exopen | 11 | 11 | 0 | 0%
lib/utils.py | (no function) | 8 | 0 | 0 | 100%
Total |  | 150 | 125 | 0 | 17%

No items found using the specified filter.